@@ -1,7 +1,7 @@
 package Config::IOD::Base;
 
-our $DATE = '2017-01-04'; # DATE
-our $VERSION = '0.29'; # VERSION
+our $DATE = '2017-01-05'; # DATE
+our $VERSION = '0.30'; # VERSION
 
 use 5.010001;
 use strict;
@@ -179,10 +179,15 @@ sub _parse_raw_value {
         } elsif ($enc eq 'path' || $enc eq 'paths') {
 
             if ($val =~ m!\A~([^/]+)?(?:/|\z)!) {
-                require File::HomeDir;
-                my $home_dir = defined($1) ?
-                    File::HomeDir->users_home($1) : File::HomeDir->my_home;
-                return ("Unknown user '$1' in path") unless $home_dir;
+                my $home_dir = length($1) ?
+                    _get_users_home_dir($1) : _get_my_home_dir();
+                unless ($home_dir) {
+                    if (length $1) {
+                        return "Can't get home directory for user '$1' in path";
+                    } else {
+                        return "Can't get home directory for current user in path";
+                    }
+                }
                 $val =~ s!\A~([^/]+)?!$home_dir!;
             }
             $val =~ s!(?<=.)/\z!!;
@@ -304,6 +309,50 @@ sub _parse_raw_value {
     # should not be reached
 }
 
+# borrowed from PERLANCAR::File::HomeDir 0.04
+sub _get_my_home_dir {
+    if ($^O eq 'MSWin32') {
+        # File::HomeDir always uses exists($ENV{x}) first, does it want to avoid
+        # accidentally creating env vars?
+        return $ENV{HOME} if $ENV{HOME};
+        return $ENV{USERPROFILE} if $ENV{USERPROFILE};
+        return join($ENV{HOMEDRIVE}, "\\", $ENV{HOMEPATH})
+            if $ENV{HOMEDRIVE} && $ENV{HOMEPATH};
+    } else {
+        return $ENV{HOME} if $ENV{HOME};
+        my @pw;
+        eval { @pw = getpwuid($>) };
+        return $pw[7] if @pw;
+    }
+
+    die "Can't get home directory";
+}
+
+# borrowed from PERLANCAR::File::HomeDir 0.05, with some modifications
+sub _get_users_home_dir {
+    my ($name) = @_;
+
+    if ($^O eq 'MSWin32') {
+        # not yet implemented
+        return undef;
+    } else {
+        # IF and only if we have getpwuid support, and the name of the user is
+        # our own, shortcut to my_home. This is needed to handle HOME
+        # environment settings.
+        if ($name eq getpwuid($<)) {
+            return _get_my_home_dir();
+        }
+
+      SCOPE: {
+            my $home = (getpwnam($name))[7];
+            return $home if $home and -d $home;
+        }
+
+        return undef;
+    }
+
+}
+
 sub _decode_json {
     my ($self, $val) = @_;
     state $json = do {
@@ -436,7 +485,7 @@ Config::IOD::Base - Base class for Config::IOD and Config::IOD::Reader
 
 =head1 VERSION
 
-This document describes version 0.29 of Config::IOD::Base (from Perl distribution Config-IOD-Reader), released on 2017-01-04.
+This document describes version 0.30 of Config::IOD::Base (from Perl distribution Config-IOD-Reader), released on 2017-01-05.
 
 =head1 EXPRESSION
 
