@@ -1,20 +1,19 @@
 package Test::Config::IOD::Common;
 
-our $DATE = '2017-01-04'; # DATE
-our $VERSION = '0.29'; # VERSION
+our $DATE = '2017-01-05'; # DATE
+our $VERSION = '0.30'; # VERSION
 
 use 5.010;
 use strict;
 use warnings;
 
-use Module::Load;
 use Test::More 0.98;
 
 our $CLASS = "Config::IOD::Reader";
 
 sub test_common_iod {
 
-    load $CLASS;
+    eval "require $CLASS"; die if $@;
 
     subtest "opt: default_section" => sub {
         test_read_iod(
@@ -280,7 +279,7 @@ Test::Config::IOD::Common - Common tests for Config::IOD and Config::IOD::Reader
 
 =head1 VERSION
 
-This document describes version 0.29 of Test::Config::IOD::Common (from Perl distribution Config-IOD-Reader), released on 2017-01-04.
+This document describes version 0.30 of Test::Config::IOD::Common (from Perl distribution Config-IOD-Reader), released on 2017-01-05.
 
 =for Pod::Coverage .+
 
